@@ -17,7 +17,7 @@ use threads;
 use threads::shared;
 
 use FindBin;
-use lib "$FindBin::RealBin/../lib/perl5";
+use lib "$FindBin::RealBin/../lib";
 use Mashtree qw/logmsg @fastqExt @fastaExt @richseqExt _truncateFilename createTreeFromPhylip $MASHTREE_VERSION/;
 use Mashtree::Db;
 use Bio::Tree::DistanceFactory;
